import matplotlib.pyplot as plt
import pandas as pd

plt.rcParams.update({'font.size': 15})

def plot_cv_from_files(base_filepath):
    # Define the suffixes for each frequency
    suffixes = ["_30K", "_100K", "_300K", "_1M", "_2M"]
    frequencies = ["30 kHz", "100 kHz", "300 kHz", "1 MHz", "2 MHz"]  # Labels for the legend

    plt.figure(figsize=(10, 6))

    for suffix, freq in zip(suffixes, frequencies):
        # Construct the filepath and read the data
        filepath = f"{base_filepath}{suffix}.csv"
        data = pd.read_csv(filepath)

        # Plot V_bias vs Cs
        plt.plot(data["V_bias"], data["Cs"] * 1e15, label=freq) #The 1e15 is for conversion to femtoFarad.

    # Plot formatting
    plt.xlabel("Bias Voltage (V)")
    plt.ylabel("Capacitance (fF)")
    plt.title("CV curve of chip 4 SPAD 3")
    plt.legend()
    plt.grid(True)

    # Show plot
    plt.show()

plot_cv_from_files("c4_s3")
