import pandas as pd
import matplotlib.pyplot as plt
import numpy as np

# List of CSV file paths
file_paths = ['c1_s1.csv', 'c1_s2.csv', 'c1_s3.csv']  # Replace with your file paths
colors = ['b', 'g', 'r']  # Colors for each plot
labels = ['Chip 1 SPAD 1', 'Chip 1 SPAD 2', 'Chip 1 SPAD 3']  # Labels for each curve

plt.rcParams.update({'font.size': 15})

# Initialize a figure
plt.figure(figsize=(10, 6))

# Loop through each file
for i, file_path in enumerate(file_paths):
    data = []
    with open(file_path, 'r') as f:
        for line in f:
            # Only add rows with actual voltage/current data
            if not line.startswith(('SetupTitle', 'PrimitiveTest', 'TestParameter', 'MetaData', 'AnalysisSetup')):
                data.append(line.strip().split(','))

    # Clean and organize the data
    cleaned_data = []
    for entry in data:
        if entry[0].strip() == 'DataValue':
            voltage = float(entry[1].strip())
            current = float(entry[2].strip())
            cleaned_data.append({'Voltage': voltage, 'Current': current})

    # Convert to a DataFrame for easier analysis
    df = pd.DataFrame(cleaned_data)

    # Convert columns to numeric
    df['Voltage'] = pd.to_numeric(df['Voltage'], errors='coerce')
    df['Current'] = pd.to_numeric(df['Current'], errors='coerce') * 1e6 #The 1e6 is for converting to micro amps.

    # Drop rows with NaN values
    df = df.dropna()

    # Plot IV curve for the current file
    plt.plot(df['Voltage'], df['Current'], linestyle='-', color=colors[i], label=labels[i])

# Final plot adjustments
plt.xlabel("Voltage (V)")
plt.ylabel("Current ($\mu$A)")
plt.title("IV curves chip 1")
plt.grid(True)
plt.legend()
plt.show()
