import pandas as pd
import matplotlib.pyplot as plt

# Load the CSV file
file_path = 'c1_s1.csv'  # Replace with your file path
data = []
with open(file_path, 'r') as f:
    for line in f:
        # Only add rows with actual voltage/current data (likely rows without "TestParameter" or "MetaData")
        if not line.startswith(('SetupTitle', 'PrimitiveTest', 'TestParameter', 'MetaData', 'AnalysisSetup')):
            data.append(line.strip().split(','))

# Clean and organize the data
cleaned_data = []
for entry in data:
    if entry[0].strip() == 'DataValue':
        voltage = float(entry[1].strip())
        current = float(entry[2].strip())
        cleaned_data.append({'Voltage': voltage, 'Current': current})

# Convert to a DataFrame for easier analysis
df = pd.DataFrame(cleaned_data)

print(df.head())

# Convert columns to numeric, setting errors to 'coerce' to handle non-numeric rows if any
df['Voltage'] = pd.to_numeric(df['Voltage'], errors='coerce')
df['Current'] = pd.to_numeric(df['Current'], errors='coerce')

# Drop rows with NaN values (from non-numeric entries)
df = df.dropna()

# Plot IV curve
plt.figure(figsize=(10, 6))
plt.plot(df['Voltage'], df['Current'], marker='o', linestyle='-', color='b', label='I/V Curve')
plt.xlabel("Voltage (V)")
plt.ylabel("Current (I)")
plt.title("IV Curve")
plt.grid(True)
plt.legend()
plt.show()
