import pandas as pd
import matplotlib.pyplot as plt
import numpy as np

# Load your three CSV files
file_paths = ['c1_s1.csv', 'c1_s2.csv', 'c1_s3.csv']  # Replace with actual file paths
labels = ["Chip 1 SPAD 1", "Chip 1 SPAD 2", "Chip 1 SPAD 3"]

dataframes = []

plt.rcParams.update({'font.size': 15})

# Process each file and append to the dataframes list
for file_path in file_paths:
    data = []
    with open(file_path, 'r') as f:
        for line in f:
            # Only add rows with actual voltage/current data
            if not line.startswith(('SetupTitle', 'PrimitiveTest', 'TestParameter', 'MetaData', 'AnalysisSetup')):
                data.append(line.strip().split(','))

    # Clean and organize the data
    cleaned_data = []
    for entry in data:
        if entry[0].strip() == 'DataValue':
            voltage = float(entry[1].strip())
            current = float(entry[2].strip()) * 1e6 #The 1e6 is to convert to micro amps
            cleaned_data.append({'Voltage': voltage, 'Current': current})

    # Convert to a DataFrame and drop NaN values
    df = pd.DataFrame(cleaned_data).dropna()
    dataframes.append(df)
    print(df)

# Plot each sweep with arrows indicating direction
plt.figure(figsize=(10, 6))
colors = ['b', 'g', 'r']  # Different color for each sweep

for i, df in enumerate(dataframes):
    # Split forward and backward sweeps based on indices
    halfway = len(df) // 2
    forward_sweep = df.iloc[:halfway]
    backward_sweep = df.iloc[halfway:]

    # Plot forward sweep with arrows
    plt.plot(forward_sweep['Voltage'], forward_sweep['Current'], linestyle='-', color=colors[i], label=labels[i]+" - Forward")
    #for j in range(0, len(forward_sweep) - 1, 10):  # Adjust the interval for fewer arrows if needed
        #plt.annotate('', xy=(forward_sweep['Voltage'].iloc[j+1], forward_sweep['Current'].iloc[j+1]),
        #             xytext=(forward_sweep['Voltage'].iloc[j], forward_sweep['Current'].iloc[j]),
        #             arrowprops=dict(arrowstyle='->', color=colors[i]))

    # Plot backward sweep with arrows
    plt.plot(backward_sweep['Voltage'], backward_sweep['Current'], linestyle='--', color=colors[i], label=labels[i]+" - Backward")
    #for j in range(0, len(backward_sweep) - 1, 10):  # Adjust the interval for fewer arrows if needed
        #plt.annotate('', xy=(backward_sweep['Voltage'].iloc[j+1], backward_sweep['Current'].iloc[j+1]),
        #             xytext=(backward_sweep['Voltage'].iloc[j], backward_sweep['Current'].iloc[j]),
        #             arrowprops=dict(arrowstyle='->', color=colors[i]))

# Customize plot
plt.xlabel("Voltage (V)")
plt.ylabel("Current ($\mu$A)")
plt.title("IV Curves chip 1")
plt.grid(True)
plt.legend()
plt.show()
